Aiuti
=====

.. image:: https://img.shields.io/pypi/v/aiuti.svg
   :target: https://pypi.python.org/pypi/aiuti
   :alt: PyPI

.. image:: https://img.shields.io/badge/license-MIT-red.svg
   :target: https://en.wikipedia.org/wiki/MIT_License
   :alt: Licence - MIT

.. image:: https://github.com/aiudirog/aiuti/workflows/tests/badge.svg
   :target: https://github.com/aiudirog/aiuti
   :alt: Tests Status

.. image:: https://readthedocs.org/projects/aiuti/badge/?version=latest
   :target: https://aiuti.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://codecov.io/gh/aiudirog/aiuti/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/aiudirog/aiuti
   :alt: Coverage Status

This Python package is my personal collection of helpers and utilities
that I have written for various projects but don't have to be maintained
with those projects.

It has no required dependencies and is MIT licenced in order to make it
as portable and easy to use as possible.

Installation
------------

This package can be installed from the official PyPI:

.. code-block:: sh

    $ pip install aiuti

Documentation
-------------

The documentation can be found on `Read the Docs
<https://aiuti.readthedocs.io/en/latest/>`__.
